/*
 * Copyright 2006 Abdulla G. Abdurakhmanov (abdulla.abdurakhmanov@gmail.com).
 * 
 * Licensed under the LGPL, Version 2 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.gnu.org/copyleft/lgpl.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * With any your questions welcome to my e-mail 
 * or blog at http://abdulla-a.blogspot.com.
 */

package org.lineargs.examples;

import java.util.Collection;

import org.lineargs.*;
import org.lineargs.constraints.*;

/**
 * HelloWorld example arguments container class 
 */
public class HelloWorldArguments {

    @Option ( name = "--str", shortName = "-s", description = "String argument")
    private String strOption;
    
    @Option ( name = "--str2", shortName = "-s2", isOptional = true, description = "This is my optional string argument")
    @RegexConstraint ( mask = ".+")
    private String strOption2 = "defaultValue";

    @Option ( name = "--int", shortName = "-i", description = "Integer argument")    
    private Integer intOption;

    @Option ( name = "--bint", shortName = "-bi", isOptional = true, description = "Bounded integer argument")    
    @RangeConstraint ( minValue = 0, maxValue = 1024 )
    private Integer bndIntOption = 1024;

    @ListOption ( name = "--list", shortName = "-l", description = "Collection of string argument")
    private Collection<String> strListOption;

    @ListOption ( name = "--int-list", shortName = "-li", description = "Collection of integer argument")
    private Collection<Integer> strIntegerOption;

    @NonameOption ( description = "Your nonane value")
    private String nonameOption;

    public String getStrOption() {
        return strOption;
    }

    public void setStrOption(String strOption) {
        this.strOption = strOption;
    }

    public String getStrOption2() {
        return strOption2;
    }

    public void setStrOption2(String strOption2) {
        this.strOption2 = strOption2;
    }

    public Integer getIntOption() {
        return intOption;
    }

    public void setIntOption(Integer intOption) {
        this.intOption = intOption;
    }

    public Integer getBndIntOption() {
        return bndIntOption;
    }

    public void setBndIntOption(Integer bndIntOption) {
        this.bndIntOption = bndIntOption;
    }

    public Collection<String> getStrListOption() {
        return strListOption;
    }

    public void setStrListOption(Collection<String> strListOption) {
        this.strListOption = strListOption;
    }

    public Collection<Integer> getStrIntegerOption() {
        return strIntegerOption;
    }

    public void setStrIntegerOption(Collection<Integer> strIntegerOption) {
        this.strIntegerOption = strIntegerOption;
    }

    public String getNonameOption() {
        return nonameOption;
    }

    public void setNonameOption(String nonameOption) {
        this.nonameOption = nonameOption;
    }
}

 /** @example HelloWorldArguments.java
  * This is an example of how to define options for LineArgs library.
  */
